<?php

/**
 * FME Extensions
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the fmeextensions.com license that is
 * available through the world-wide-web at this URL:
 * https://www.fmeextensions.com/LICENSE.txt
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade this extension to newer
 * version in the future.
 *
 * @category  FME Calalog
 * @author    FME extensions <support@fmeextensions.com
>
 * @package   FME_CopyCategory
 * @copyright Copyright (c) 2021 FME (http://fmeextensions.com/
)
 * @license   https://fmeextensions.com/LICENSE.txt
 */

namespace FME\CopyCategory\Block\Adminhtml\Category\Edit;

use Magento\Backend\Block\Widget\Context;
use Magento\Cms\Api\PageRepositoryInterface;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\View\Element\UiComponent\Control\ButtonProviderInterface;

/**
 * Description of CopyCategory
 *
 * @author usol
 */
class CopyCategory implements ButtonProviderInterface
{

    /**
     * @return array
     */
    public function __construct(
        Context $context,
        \Magento\Framework\Registry $registry,
        \Magento\Store\Model\StoreManagerInterface $storeManager
    ) {
        $this->_storeManager = $storeManager;
        $this->context = $context;
        $this->_coreRegistry = $registry;
    }

    /**
     * @return array
     */
    public function getButtonData()
    {
        $category = $this->getCategory();
        $categoryId = (int) $category->getId();
        if ($categoryId && !in_array($categoryId, $this->getRootIds()) && $category->isDeleteable()) {
            return [
                'id' => 'copy-category',
                'label' => __('Copy Category'),
                'on_click' => sprintf("location.href = '%s';", $this->getCopyCategoryUrl()),
                'class' => 'save primary',
                'sort_order' => 10
            ];
        }

        return [];
    }

    public function getCategory()
    {
        return $this->_coreRegistry->registry('category');
    }

    public function getRootIds()
    {
        $ids = [\Magento\Catalog\Model\Category::TREE_ROOT_ID];
        foreach ($this->_storeManager->getGroups() as $store) {
            $ids[] = $store->getRootCategoryId();
        }
        return $ids;
    }

    /**
     * @return string
     */
    public function getCopyCategoryUrl()
    {
        return $this->getUrl('copycategory/index/index', ['id' => $this->getCategoryId()]);
    }

    public function getUrl($route = '', $params = [])
    {
        return $this->context->getUrlBuilder()->getUrl($route, $params);
    }

    public function getCategoryId()
    {
        $category = $this->getCategory();
        return (int) $category->getId();
    }
}
